@@ -1,23 +1,25 @@
-/* $Id: proclist.h,v 1.13 1998/10/11 18:14:04 martin Exp $ */
+/* $Id: proclist.h,v 1.17 1999/02/23 11:43:05 martin Exp $ */
+
+/* Copyright (C) 1998-99 Martin Baulig
+   This file is part of LibGTop 1.0.
 
-/* Copyright (C) 1995, 1996, 1997 Free Software Foundation, Inc.
-   This file is part of the Gnome Top Library.
    Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.
 
-   The Gnome Top Library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   LibGTop is free software; you can redistribute it and/or modify it
+   under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License,
+   or (at your option) any later version.
 
-   The Gnome Top Library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   LibGTop is distributed in the hope that it will be useful, but WITHOUT
+   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Library General Public
-   License along with the GNU C Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with LibGTop; see the file COPYING. If not, write to the
+   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+*/
 
 #ifndef __GLIBTOP_PROCLIST_H__
 #define __GLIBTOP_PROCLIST_H__
@@ -25,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-__BEGIN_DECLS
+BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_PROCLIST_NUMBER	0
 #define GLIBTOP_PROCLIST_TOTAL	1
@@ -68,14 +70,22 @@ struct _glibtop_proclist
 #define glibtop_get_proclist_r		glibtop_get_proclist_s
 #endif
 
-extern unsigned *glibtop_get_proclist_l __P((glibtop *, glibtop_proclist *, int64_t, int64_t));
+unsigned *
+glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
+			int64_t which, int64_t arg);
 
 #if GLIBTOP_SUID_PROCLIST
-extern void glibtop_init_proclist_p __P((glibtop *));
-extern unsigned *glibtop_get_proclist_p __P((glibtop *, glibtop_proclist *, int64_t, int64_t));
+void glibtop_init_proclist_p (glibtop *server);
+
+unsigned *
+glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
+			int64_t which, int64_t arg);
 #else
-extern void glibtop_init_proclist_s __P((glibtop *));
-extern unsigned *glibtop_get_proclist_s __P((glibtop *, glibtop_proclist *, int64_t, int64_t));
+void glibtop_init_proclist_s (glibtop *server);
+
+unsigned *
+glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
+			int64_t which, int64_t arg);
 #endif
 
 #ifdef GLIBTOP_NAMES
@@ -89,6 +99,6 @@ extern const char *glibtop_descriptions_proclist [];
 
 #endif
 
-__END_DECLS
+END_LIBGTOP_DECLS
 
 #endif
