@@ -1,4 +1,4 @@
-/* $Id: swap.c,v 1.13 1999/03/01 15:33:30 martin Exp $ */
+/* $Id: swap.c,v 1.13.4.3 1999/05/27 18:56:53 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -30,19 +30,28 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_swap =
-(1 << GLIBTOP_SWAP_TOTAL) + (1 << GLIBTOP_SWAP_USED) +
-(1 << GLIBTOP_SWAP_FREE) + (1 << GLIBTOP_SWAP_PAGEIN) +
-(1 << GLIBTOP_SWAP_PAGEOUT);
+(1L << GLIBTOP_SWAP_TOTAL) + (1L << GLIBTOP_SWAP_USED) +
+(1L << GLIBTOP_SWAP_FREE) + (1L << GLIBTOP_SWAP_PAGEIN) +
+(1L << GLIBTOP_SWAP_PAGEOUT);
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__bsdi__)
 
 #include <sys/conf.h>
+#ifdef __bsdi__
+#include <vm/swap_pager.h>
+#else
 #include <sys/rlist.h>
+#endif
 #include <sys/vmmeter.h>
 
-#if __FreeBSD__ < 4
-
 /* nlist structure for kernel access */
+
+#if defined(__bsdi__)
+static struct nlist nlst [] = {
+	{ "_swapstats" }, /* general swap info */
+	{ 0 }
+};
+#elif __FreeBSD__ < 4
 static struct nlist nlst [] = {
 #define VM_SWAPLIST	0
 	{ "_swaplist" },/* list of free swap areas */
@@ -56,28 +65,36 @@ static struct nlist nlst [] = {
 	{ "_dmmax" },	/* maximum size of a swap block */
 	{ 0 }
 };
-
 #endif
 
-#elif (defined __NetBSD__)
+#elif defined(__NetBSD__)
 
+#if (__NetBSD_Version__ >= 104000000)
+#include <uvm/uvm_extern.h>
+#include <sys/swap.h>
+#else
 #include <vm/vm_swap.h>
+#endif
 
 #endif
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+static int mib_uvmexp [] = { CTL_VM, VM_UVMEXP };
+#else
 /* nlist structure for kernel access */
 static struct nlist nlst2 [] = {
 	{ "_cnt" },
 	{ 0 }
 };
+#endif
 
 /* Init function. */
 
 void
 glibtop_init_swap_p (glibtop *server)
 {
-#ifdef __FreeBSD__
-#if __FreeBSD__ < 4
+#if defined(__FreeBSD__) || defined(__bsdi__)
+#if __FreeBSD__ < 4 || defined(__bsdi__)
 	if (kvm_nlist (server->machine.kd, nlst) != 0) {
 		glibtop_warn_io_r (server, "kvm_nlist (swap)");
 		return;
@@ -86,16 +103,18 @@ glibtop_init_swap_p (glibtop *server)
 	struct kvm_swap dummy;
 
 	if (kvm_getswapinfo (server->machine.kd, &dummy, 1, 0) != 0) {
-		glibtop_warn_io_r (server, "kvm_nlist (swap)");
+		glibtop_warn_io_r (server, "kvm_swap (swap)");
 		return;
 	}
 #endif
 #endif
 
+#if !(defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000))
 	if (kvm_nlist (server->machine.kd, nlst2) != 0) {
-		glibtop_warn_io_r (server, "kvm_nlist (swap)");
+		glibtop_warn_io_r (server, "kvm_nlist (cnt)");
 		return;
 	}
+#endif
 
 	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
@@ -110,8 +129,9 @@ glibtop_init_swap_p (glibtop *server)
 void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-#ifdef __FreeBSD__
-#if __FreeBSD__ < 4
+#if defined(__FreeBSD__)
+
+# if __FreeBSD__ < 4
 	char *header;
 	int hlen, nswdev, dmmax;
 	int div, nfree, npfree;
@@ -122,29 +142,44 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 	struct rlist *swapptr;
 	size_t sw_size;
 	u_long ptr;
-#else
+# else
 	int nswdev;
 	struct kvm_swap kvmsw[16];
-#endif
-#elif (defined __NetBSD__)
+# endif
+
+#elif defined(__bsdi__)	
+	struct swapstats swap;
+#elif defined(__NetBSD__)
 	struct swapent *swaplist;
 #endif
 
 	int nswap, i;
 	int avail = 0, inuse = 0;
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	struct uvmexp uvmexp;
+	size_t length_uvmexp;
+#else
 	/* To get `pagein' and `pageout'. */
 	struct vmmeter vmm;
+#endif
         static int swappgsin = -1;
 	static int swappgsout = -1;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_SWAP), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_SWAP), 0);
 	
 	memset (buf, 0, sizeof (glibtop_swap));
 
 	if (server->sysdeps.swap == 0)
 		return;
 
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	length_uvmexp = sizeof (uvmexp);
+	if (sysctl (mib_uvmexp, 2, &uvmexp, &length_uvmexp, NULL, 0)) {
+		glibtop_warn_io_r (server, "sysctl (uvmexp)");
+		return;
+	}
+#else
 	/* This is used to get the `pagein' and `pageout' members. */
 	
 	if (kvm_read (server->machine.kd, nlst2[0].n_value,
@@ -152,6 +187,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 		glibtop_warn_io_r (server, "kvm_read (cnt)");
 		return;
 	}
+#endif
 
         if (swappgsin < 0) {
 		buf->pagein = 0;
@@ -160,21 +196,31 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 #ifdef __FreeBSD__
 		buf->pagein = vmm.v_swappgsin - swappgsin;
 		buf->pageout = vmm.v_swappgsout - swappgsout;
+#else
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+		buf->pagein = uvmexp.swapins - swappgsin;
+		buf->pageout = uvmexp.swapouts - swappgsout;
 #else
 		buf->pagein = vmm.v_swpin - swappgsin;
 		buf->pageout = vmm.v_swpout - swappgsout;
+#endif
 #endif
 	}
 
 #ifdef __FreeBSD__
         swappgsin = vmm.v_swappgsin;
 	swappgsout = vmm.v_swappgsout;
+#else
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	swappgsin = uvmexp.swapins;
+	swappgsout = uvmexp.swapouts;
 #else
 	swappgsin = vmm.v_swpin;
 	swappgsout = vmm.v_swpout;
 #endif
+#endif
 
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__)
 
 #if __FreeBSD__ < 4
 
@@ -214,7 +260,7 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 	if (kvm_read (server->machine.kd, nlst[VM_SWDEVT].n_value,
 		      &ptr, sizeof (ptr)) != sizeof (ptr)) {
-		glibtop_warn_io_r (server, "kvm_read (swaplist)");
+		glibtop_warn_io_r (server, "kvm_read (swdevt)");
 		return;
 	}
 
@@ -328,7 +374,24 @@ glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 
 #endif
 
-#elif (defined __NetBSD__)
+#elif defined(__bsdi__)
+
+	/* General info about swap devices. */
+
+	if (kvm_read (server->machine.kd, nlst[0].n_value,
+		      &swap, sizeof (swap)) != sizeof (swap)) {
+		glibtop_warn_io_r (server, "kvm_read (swap)");
+		return;
+	}
+
+	buf->flags = _glibtop_sysdeps_swap;
+
+	buf->used = swap.swap_total - swap.swap_free;
+	buf->free = swap.swap_free;
+
+	buf->total = swap.swap_total;
+
+#elif defined(__NetBSD__)
 
 	nswap = swapctl (SWAP_NSWAP, NULL, 0);
 	if (nswap < 0) {
